@@ -21,11 +21,10 @@
         #define FMT_USE_WINDOWS_H 0
     #endif
 
-    #include <spdlog/fmt/bundled/core.h>
+    #include <spdlog/fmt/bundled/base.h>
     #include <spdlog/fmt/bundled/format.h>
 
 #else  // SPDLOG_FMT_EXTERNAL is defined - use external fmtlib
-    #include <fmt/core.h>
+    #include <fmt/base.h>
     #include <fmt/format.h>
-    #include <fmt/xchar.h>
 #endif
